@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-search.c,v 1.12 2006/06/18 09:05:20 paolo Exp $
+ * $Id: gedit-commands-search.c,v 1.13 2006/12/02 15:03:22 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -759,7 +759,7 @@ _gedit_cmd_search_goto_line (GtkAction   *action,
 }
 
 void
-_gedit_cmd_search_interactive_search (GtkAction   *action,
+_gedit_cmd_search_incremental_search (GtkAction   *action,
 				      GeditWindow *window)
 {
 	GeditView *active_view;
@@ -771,10 +771,10 @@ _gedit_cmd_search_interactive_search (GtkAction   *action,
 		return;
 
 	/* Focus the view if needed: we need to focus the view otherwise 
-	   activating the binding for interactive search has no effect */
+	   activating the binding for incremental search has no effect */
 	gtk_widget_grab_focus (GTK_WIDGET (active_view));
 	
-	/* interactive search is builtin in GeditView, just activate
+	/* incremental search is builtin in GeditView, just activate
 	 * the corrisponding binding.
 	 */
 	gtk_bindings_activate (GTK_OBJECT (active_view),
