@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.h,v 1.38 2006/04/20 17:01:13 paolo Exp $
+ * $Id: gedit-utils.h,v 1.39 2006/05/02 10:07:47 sfre Exp $
  */
 
 #ifndef __GEDIT_UTILS_H__
@@ -61,6 +61,13 @@ void		 gedit_utils_menu_position_under_widget (GtkMenu  *menu,
 							 gboolean *push_in,
 							 gpointer  user_data);
 
+void		 gedit_utils_menu_position_under_tree_view
+							(GtkMenu  *menu,
+							 gint     *x,
+							 gint     *y,
+							 gboolean *push_in,
+							 gpointer  user_data);
+
 GtkWidget	*gedit_gtk_button_new_with_stock_icon	(const gchar *label,
 							 const gchar *stock_id);
 
